@@ -15,9 +15,12 @@ import numpy as np
 
 try:
     from tflite_runtime.interpreter import Interpreter
+    from tflite_runtime.interpreter import load_delegate
 except ImportError:
     sys.exit("No TensorFlow Lite Runtime module found!")
 
+from multiprocessing import cpu_count
+
 from pyvar.ml.config import CLASSIFICATION
 from pyvar.ml.config import DETECTION
 from pyvar.ml.utils.timer import Timer
@@ -34,19 +37,36 @@ class TFLiteInterpreter:
     :ivar k: number of top results;
     :ivar confidence: confidence score, default is 0.5.
     """
-    def __init__(self, model_file_path=None):
+    def __init__(self, model_file_path=None, num_threads=1, ext_delegate=None):
         """
         Constructor method for the TensorFlow Lite class.
         """
+        max_threads = cpu_count()
+
+        ext_delegate_options = {}
+        if ext_delegate is None:
+            ext_delegate_path = "/usr/lib/libvx_delegate.so"
+            ext_delegate = [load_delegate(
+                                        ext_delegate_path, ext_delegate_options)]
+
         if not os.path.isfile(model_file_path):
             raise ValueError("Must pass a labels file")
         if not model_file_path.endswith(".tflite"):
             raise TypeError(f"Expects {model_file_path} to be a text file")
+        if not num_threads:
+            num_threads = 1
+        elif num_threads > max_threads:
+            raise ValueError(f"num_threads can't be greater than"
+                             f" {max_threads}.")
+
         self.model_file_path = model_file_path
-        self.interpreter = Interpreter(model_path=self.model_file_path)
+        self.interpreter = Interpreter(model_path=self.model_file_path,
+                                       experimental_delegates=ext_delegate,
+                                       num_threads=num_threads)
         self.interpreter.allocate_tensors()
         self.input_details = self.interpreter.get_input_details()
         self.output_details = self.interpreter.get_output_details()
+        self.interpreter.invoke()
         self.result = None
         self.inference_time = None
         self.k = 3
@@ -156,7 +176,6 @@ class TFLiteInterpreter:
         """
         Runs inference on the image/frame set in the set_input() method.
         """
-        self.interpreter.invoke()  # ignores the warm-up time.
         timer = Timer()
         with timer.timeit():
             self.interpreter.invoke()
